==> openttd-1.9.0-beta1-docs.tar.tar: openttd-1.9.0-beta1-docs/html/d7/df8/framerate__widget_8h.js <==
var framerate__widget_8h =
[
    [ "FramerateWindowWidgets", "d7/df8/framerate__widget_8h.html#a2cda64b6a1eac7e0be90e83d980b98f7", [
      [ "WID_FRW_CAPTION", "d7/df8/framerate__widget_8h.html#a2cda64b6a1eac7e0be90e83d980b98f7a30f16532515a9c5fcac93721e72e2e0e", null ],
      [ "WID_FRW_RATE_GAMELOOP", "d7/df8/framerate__widget_8h.html#a2cda64b6a1eac7e0be90e83d980b98f7a6b70340b3b576836fa15b32d8a88c1e4", null ],
      [ "WID_FRW_RATE_DRAWING", "d7/df8/framerate__widget_8h.html#a2cda64b6a1eac7e0be90e83d980b98f7a93fe4d712733b6170ae3fefab00fabf3", null ],
      [ "WID_FRW_RATE_FACTOR", "d7/df8/framerate__widget_8h.html#a2cda64b6a1eac7e0be90e83d980b98f7a3a47b22b6098a82cac73d351c94e3b29", null ],
      [ "WID_FRW_INFO_DATA_POINTS", "d7/df8/framerate__widget_8h.html#a2cda64b6a1eac7e0be90e83d980b98f7a7dd8d66257cfe7c1dc96ad5e64d9a314", null ],
      [ "WID_FRW_TIMES_NAMES", "d7/df8/framerate__widget_8h.html#a2cda64b6a1eac7e0be90e83d980b98f7a2d04c843ddd3641d59c4d740527027d9", null ],
      [ "WID_FRW_TIMES_CURRENT", "d7/df8/framerate__widget_8h.html#a2cda64b6a1eac7e0be90e83d980b98f7a730d2bd93b24c553d1e67fd3f8aaa47a", null ],
      [ "WID_FRW_TIMES_AVERAGE", "d7/df8/framerate__widget_8h.html#a2cda64b6a1eac7e0be90e83d980b98f7a034ccd8c309c814b84da267f475b1e6e", null ]
    ] ],
    [ "FrametimeGraphWindowWidgets", "d7/df8/framerate__widget_8h.html#a82867c567d51397cc16a505a616e3d79", [
      [ "WID_FGW_CAPTION", "d7/df8/framerate__widget_8h.html#a82867c567d51397cc16a505a616e3d79a61e1a2233976ac8553aceb2f3d51f7fa", null ],
      [ "WID_FGW_GRAPH", "d7/df8/framerate__widget_8h.html#a82867c567d51397cc16a505a616e3d79ae100060c28ead2a026b00b12239eca34", null ]
    ] ]
];

==> openttd-1.11.0-beta1-docs.tar.tar: openttd-1.11.0-beta1-docs/html/d7/df8/framerate__widget_8h.js <==
var framerate__widget_8h =
[
    [ "FramerateWindowWidgets", "d7/df8/framerate__widget_8h.html#a2cda64b6a1eac7e0be90e83d980b98f7", [
      [ "WID_FRW_CAPTION", "d7/df8/framerate__widget_8h.html#a2cda64b6a1eac7e0be90e83d980b98f7a30f16532515a9c5fcac93721e72e2e0e", null ],
      [ "WID_FRW_RATE_GAMELOOP", "d7/df8/framerate__widget_8h.html#a2cda64b6a1eac7e0be90e83d980b98f7a6b70340b3b576836fa15b32d8a88c1e4", null ],
      [ "WID_FRW_RATE_DRAWING", "d7/df8/framerate__widget_8h.html#a2cda64b6a1eac7e0be90e83d980b98f7a93fe4d712733b6170ae3fefab00fabf3", null ],
      [ "WID_FRW_RATE_FACTOR", "d7/df8/framerate__widget_8h.html#a2cda64b6a1eac7e0be90e83d980b98f7a3a47b22b6098a82cac73d351c94e3b29", null ],
      [ "WID_FRW_INFO_DATA_POINTS", "d7/df8/framerate__widget_8h.html#a2cda64b6a1eac7e0be90e83d980b98f7a7dd8d66257cfe7c1dc96ad5e64d9a314", null ],
      [ "WID_FRW_TIMES_NAMES", "d7/df8/framerate__widget_8h.html#a2cda64b6a1eac7e0be90e83d980b98f7a2d04c843ddd3641d59c4d740527027d9", null ],
      [ "WID_FRW_TIMES_CURRENT", "d7/df8/framerate__widget_8h.html#a2cda64b6a1eac7e0be90e83d980b98f7a730d2bd93b24c553d1e67fd3f8aaa47a", null ],
      [ "WID_FRW_TIMES_AVERAGE", "d7/df8/framerate__widget_8h.html#a2cda64b6a1eac7e0be90e83d980b98f7a034ccd8c309c814b84da267f475b1e6e", null ],
      [ "WID_FRW_ALLOCSIZE", "d7/df8/framerate__widget_8h.html#a2cda64b6a1eac7e0be90e83d980b98f7ae24fb488238258407379fd7b1d507399", null ],
      [ "WID_FRW_SEL_MEMORY", "d7/df8/framerate__widget_8h.html#a2cda64b6a1eac7e0be90e83d980b98f7a912548a2879e04a3f23f57e1516c7620", null ],
      [ "WID_FRW_SCROLLBAR", "d7/df8/framerate__widget_8h.html#a2cda64b6a1eac7e0be90e83d980b98f7acbe53ce33e15f33183c5c895f61c2511", null ]
    ] ],
    [ "FrametimeGraphWindowWidgets", "d7/df8/framerate__widget_8h.html#a82867c567d51397cc16a505a616e3d79", [
      [ "WID_FGW_CAPTION", "d7/df8/framerate__widget_8h.html#a82867c567d51397cc16a505a616e3d79a61e1a2233976ac8553aceb2f3d51f7fa", null ],
      [ "WID_FGW_GRAPH", "d7/df8/framerate__widget_8h.html#a82867c567d51397cc16a505a616e3d79ae100060c28ead2a026b00b12239eca34", null ]
    ] ]
];
